@@ -12,13 +12,17 @@
 #
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+try:
+    from PySide6.QtWidgets import QHeaderView, QDoubleSpinBox, QPushButton, QComboBox,  QMenu, QTreeView, QSplitter, QSizePolicy, QGridLayout, QHBoxLayout, QVBoxLayout, QMenu, QTableWidgetItem, QAbstractItemView, QApplication, QToolBar, QMenuBar, QStatusBar, QTableWidget, QMainWindow, QWidget, QFrame, QAbstractItemView, QCheckBox, QSpinBox, QLabel
+    from PySide6.QtGui import QShortcut, QAction, QCursor, QKeySequence, QIcon, QStandardItemModel, QStandardItem
+    from PySide6.QtCore import QCoreApplication, QRect, QSize, Qt, QTranslator, QLocale
+except:
+    from PyQt5.QtWidgets import QHeaderView, QShortcut, QDoubleSpinBox, QPushButton, QComboBox,  QMenu, QTreeView, QSplitter, QSizePolicy, QGridLayout, QHBoxLayout, QVBoxLayout, QMenu, QTableWidgetItem, QAbstractItemView, QApplication, QToolBar, QMenuBar, QStatusBar, QTableWidget, QAction, QMainWindow, QWidget, QFrame, QAbstractItemView, QCheckBox, QSpinBox, QLabel
+    from PyQt5.QtGui import QCursor, QKeySequence, QIcon, QStandardItemModel, QStandardItem
+    from PyQt5.QtCore import QCoreApplication, QRect, QSize, Qt, QTranslator, QLocale
 
-from PyQt5.QtWidgets import QShortcut, QDoubleSpinBox, QPushButton, QComboBox,  QMenu, QTreeView, QSplitter, QSizePolicy, QGridLayout, QHBoxLayout, QVBoxLayout, QMenu, QTableWidgetItem, QAbstractItemView, QApplication, QToolBar, QMenuBar, QStatusBar, QTableWidget, QAction, QMainWindow, QWidget, QFrame, QAbstractItemView, QCheckBox, QSpinBox, QLabel
-from PyQt5.QtGui import QCursor, QKeySequence, QIcon, QStandardItemModel, QStandardItem
-from PyQt5.QtCore import QCoreApplication, QRect, QSize, Qt, QTranslator, QLocale
-from persepolis.gui.customized_widgets import MyQDateTimeEdit
 from persepolis.gui import resources
-
+from persepolis.gui.customized_widgets import MyQDateTimeEdit
 
 # align center for items in download table
 class QTableWidgetItem(QTableWidgetItem):
@@ -161,6 +165,9 @@ class DownloadTableWidget(QTableWidget):
         # creating context menu
         self.tablewidget_menu = QMenu(self)
         self.sendMenu = self.tablewidget_menu.addMenu('')
+        
+        # don't wrap items 
+        self.setWordWrap(False)
 
     def contextMenuEvent(self, event):
         self.tablewidget_menu.popup(QCursor.pos())
@@ -183,7 +190,7 @@ class CategoryTreeView(QTreeView):
         # creating context menu
         self.category_tree_menu = QMenu(self)
 
-        # connecting actication  event
+        # connecting activation  event
         self.activated.connect(parent.categoryTreeSelected)
         self.pressed.connect(parent.categoryTreeSelected)
 
@@ -394,17 +401,17 @@ class MainWindow_Ui(QMainWindow):
         self.download_table.setEditTriggers(QAbstractItemView.NoEditTriggers)
         self.download_table.verticalHeader().hide()
 
-        # hide gid and download dictioanry section
+        # hide column of GID and column of link.
         self.download_table.setColumnHidden(8, True)
         self.download_table.setColumnHidden(9, True)
 
         download_table_header = [QCoreApplication.translate("mainwindow_ui_tr", 'File Name'), QCoreApplication.translate("mainwindow_ui_tr", 'Status'), QCoreApplication.translate("mainwindow_ui_tr", 'Size'), QCoreApplication.translate("mainwindow_ui_tr", 'Downloaded'), QCoreApplication.translate("mainwindow_ui_tr", 'Percentage'), QCoreApplication.translate("mainwindow_ui_tr", 'Connections'),
-                                 QCoreApplication.translate("mainwindow_ui_tr", 'Transfer rate'), QCoreApplication.translate("mainwindow_ui_tr", 'Estimated time left'), 'Gid', QCoreApplication.translate("mainwindow_ui_tr", 'Link'), QCoreApplication.translate("mainwindow_ui_tr", 'First try date'), QCoreApplication.translate("mainwindow_ui_tr", 'Last try date'), QCoreApplication.translate("mainwindow_ui_tr", 'Category')]
+                                 QCoreApplication.translate("mainwindow_ui_tr", 'Transfer Rate'), QCoreApplication.translate("mainwindow_ui_tr", 'Estimated Time Left'), 'Gid', QCoreApplication.translate("mainwindow_ui_tr", 'Link'), QCoreApplication.translate("mainwindow_ui_tr", 'First Try Date'), QCoreApplication.translate("mainwindow_ui_tr", 'Last Try Date'), QCoreApplication.translate("mainwindow_ui_tr", 'Category')]
 
         self.download_table.setHorizontalHeaderLabels(download_table_header)
 
         # fixing the size of download_table when window is Maximized!
-        self.download_table.horizontalHeader().setSectionResizeMode(0)
+        self.download_table.horizontalHeader().setSectionResizeMode(QHeaderView.ResizeMode.Interactive)
         self.download_table.horizontalHeader().setStretchLastSection(True)
 
         horizontal_splitter.setStretchFactor(0, 3)  # category_tree width
@@ -486,7 +493,7 @@ class MainWindow_Ui(QMainWindow):
         self.persepolis_setting.beginGroup('settings/shortcuts')
 
         # videoFinderAddLinkAction
-        self.videoFinderAddLinkAction = QAction(QIcon(icons + 'video_finder'), QCoreApplication.translate("mainwindow_ui_tr", 'Find Video Links'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Download video or audio from Youtube, Vimeo, etc...'),
+        self.videoFinderAddLinkAction = QAction(QIcon(icons + 'video_finder'), QCoreApplication.translate("mainwindow_ui_tr", 'Find Video Links...'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Download video or audio from Youtube, Vimeo, etc.'),
                                                 triggered=self.showVideoFinderAddLinkWindow)
 
         self.videoFinderAddLinkAction_shortcut = QShortcut(self.persepolis_setting.value(
@@ -495,63 +502,63 @@ class MainWindow_Ui(QMainWindow):
         videoFinderMenu.addAction(self.videoFinderAddLinkAction)
 
         # stopAllAction
-        self.stopAllAction = QAction(QIcon(icons + 'stop_all'), QCoreApplication.translate("mainwindow_ui_tr", 'Stop all active downloads'),
-                                     self, statusTip='Stop all active downloads', triggered=self.stopAllDownloads)
+        self.stopAllAction = QAction(QIcon(icons + 'stop_all'), QCoreApplication.translate("mainwindow_ui_tr", 'Stop All Active Downloads'),
+                                     self, statusTip='Stop All Active Downloads', triggered=self.stopAllDownloads)
         downloadMenu.addAction(self.stopAllAction)
 
         # sort_file_name_Action
         self.sort_file_name_Action = QAction(
-            QCoreApplication.translate("mainwindow_ui_tr", 'File name'), self, triggered=self.sortByName)
+            QCoreApplication.translate("mainwindow_ui_tr", 'File Name'), self, triggered=self.sortByName)
         sortMenu.addAction(self.sort_file_name_Action)
 
         # sort_file_size_Action
         self.sort_file_size_Action = QAction(
-            QCoreApplication.translate("mainwindow_ui_tr", 'File size'), self, triggered=self.sortBySize)
+            QCoreApplication.translate("mainwindow_ui_tr", 'File Size'), self, triggered=self.sortBySize)
         sortMenu.addAction(self.sort_file_size_Action)
 
         # sort_first_try_date_Action
         self.sort_first_try_date_Action = QAction(
-            QCoreApplication.translate("mainwindow_ui_tr", 'First try date'), self, triggered=self.sortByFirstTry)
+            QCoreApplication.translate("mainwindow_ui_tr", 'First Try Date'), self, triggered=self.sortByFirstTry)
         sortMenu.addAction(self.sort_first_try_date_Action)
 
         # sort_last_try_date_Action
         self.sort_last_try_date_Action = QAction(
-            QCoreApplication.translate("mainwindow_ui_tr", 'Last try date'), self, triggered=self.sortByLastTry)
+            QCoreApplication.translate("mainwindow_ui_tr", 'Last Try Date'), self, triggered=self.sortByLastTry)
         sortMenu.addAction(self.sort_last_try_date_Action)
 
         # sort_download_status_Action
         self.sort_download_status_Action = QAction(
-            QCoreApplication.translate("mainwindow_ui_tr", 'Download status'), self, triggered=self.sortByStatus)
+            QCoreApplication.translate("mainwindow_ui_tr", 'Download Status'), self, triggered=self.sortByStatus)
         sortMenu.addAction(self.sort_download_status_Action)
 
         # trayAction
-        self.trayAction = QAction(QCoreApplication.translate("mainwindow_ui_tr", 'Show system tray icon'), self,
+        self.trayAction = QAction(QCoreApplication.translate("mainwindow_ui_tr", 'Show System Tray Icon'), self,
                                   statusTip=QCoreApplication.translate("mainwindow_ui_tr", "Show/Hide system tray icon"), triggered=self.showTray)
         self.trayAction.setCheckable(True)
         viewMenu.addAction(self.trayAction)
 
         # showMenuBarAction
         self.showMenuBarAction = QAction(
-            QCoreApplication.translate("mainwindow_ui_tr", 'Show menubar'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Show menubar'), triggered=self.showMenuBar)
+            QCoreApplication.translate("mainwindow_ui_tr", 'Show Menubar'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Show Menubar'), triggered=self.showMenuBar)
         self.showMenuBarAction.setCheckable(True)
         viewMenu.addAction(self.showMenuBarAction)
 
         # showSidePanelAction
         self.showSidePanelAction = QAction(
-            QCoreApplication.translate("mainwindow_ui_tr", 'Show side panel'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Show side panel'), triggered=self.showSidePanel)
+            QCoreApplication.translate("mainwindow_ui_tr", 'Show Side Panel'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Show Side Panel'), triggered=self.showSidePanel)
         self.showSidePanelAction.setCheckable(True)
         viewMenu.addAction(self.showSidePanelAction)
 
         # minimizeAction
-        self.minimizeAction = QAction(QIcon(icons + 'minimize'), QCoreApplication.translate("mainwindow_ui_tr", 'Minimize to system tray'), self,
-                                      statusTip=QCoreApplication.translate("mainwindow_ui_tr", "Minimize to system tray"), triggered=self.minMaxTray)
+        self.minimizeAction = QAction(QIcon(icons + 'minimize'), QCoreApplication.translate("mainwindow_ui_tr", 'Minimize to System Tray'), self,
+                                      statusTip=QCoreApplication.translate("mainwindow_ui_tr", "Minimize to System Tray"), triggered=self.minMaxTray)
 
         self.minimizeAction_shortcut = QShortcut(
             self.persepolis_setting.value('hide_window_shortcut'), self, self.minMaxTray)
         viewMenu.addAction(self.minimizeAction)
 
         # addlinkAction
-        self.addlinkAction = QAction(QIcon(icons + 'add'), QCoreApplication.translate("mainwindow_ui_tr", 'Add New Download Link'), self,
+        self.addlinkAction = QAction(QIcon(icons + 'add'), QCoreApplication.translate("mainwindow_ui_tr", 'Add New Download Link...'), self,
                                      statusTip=QCoreApplication.translate("mainwindow_ui_tr", "Add New Download Link"), triggered=self.addLinkButtonPressed)
 
         self.addlinkAction_shortcut = QShortcut(self.persepolis_setting.value(
@@ -559,8 +566,8 @@ class MainWindow_Ui(QMainWindow):
         fileMenu.addAction(self.addlinkAction)
 
         # importText
-        self.addtextfileAction = QAction(QIcon(icons + 'file'), QCoreApplication.translate("mainwindow_ui_tr", 'Import links from text file'), self,
-                                         statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Create a Text file and put links in it.line by line!'), triggered=self.importText)
+        self.addtextfileAction = QAction(QIcon(icons + 'file'), QCoreApplication.translate("mainwindow_ui_tr", 'Import Links from Text File...'), self,
+                                         statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Create a text file and put links in it, line by line!'), triggered=self.importText)
 
         self.addtextfileAction_shortcut = QShortcut(
             self.persepolis_setting.value('import_text_shortcut'), self, self.importText)
@@ -599,18 +606,18 @@ class MainWindow_Ui(QMainWindow):
 
         # openFileAction
         self.openFileAction = QAction(QIcon(
-            icons + 'file'), QCoreApplication.translate("mainwindow_ui_tr", 'Open file'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Open file'), triggered=self.openFile)
+            icons + 'file'), QCoreApplication.translate("mainwindow_ui_tr", 'Open File...'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Open File...'), triggered=self.openFile)
         fileMenu.addAction(self.openFileAction)
 
         # openDownloadFolderAction
         self.openDownloadFolderAction = QAction(QIcon(
-            icons + 'folder'), QCoreApplication.translate("mainwindow_ui_tr", 'Open download folder'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Open download folder'), triggered=self.openDownloadFolder)
+            icons + 'folder'), QCoreApplication.translate("mainwindow_ui_tr", 'Open Download Folder'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Open Download Folder'), triggered=self.openDownloadFolder)
 
         fileMenu.addAction(self.openDownloadFolderAction)
 
         # openDefaultDownloadFolderAction
         self.openDefaultDownloadFolderAction = QAction(QIcon(
-            icons + 'folder'), QCoreApplication.translate("mainwindow_ui_tr", 'Open default download folder'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Open default download folder'), triggered=self.openDefaultDownloadFolder)
+            icons + 'folder'), QCoreApplication.translate("mainwindow_ui_tr", 'Open Default Download Folder'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Open Default Download Folder'), triggered=self.openDefaultDownloadFolder)
 
         fileMenu.addAction(self.openDefaultDownloadFolderAction)
 
@@ -623,13 +630,13 @@ class MainWindow_Ui(QMainWindow):
         fileMenu.addAction(self.exitAction)
 
         # clearAction
-        self.clearAction = QAction(QIcon(icons + 'multi_remove'), QCoreApplication.translate("mainwindow_ui_tr", 'Clear download list'),
+        self.clearAction = QAction(QIcon(icons + 'multi_remove'), QCoreApplication.translate("mainwindow_ui_tr", 'Clear Download List'),
                                    self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Clear all items in download list'), triggered=self.clearDownloadList)
         editMenu.addAction(self.clearAction)
 
         # removeSelectedAction
-        self.removeSelectedAction = QAction(QIcon(icons + 'remove'), QCoreApplication.translate("mainwindow_ui_tr", 'Remove selected downloads from list'),
-                                            self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Remove selected downloads form list'), triggered=self.removeSelected)
+        self.removeSelectedAction = QAction(QIcon(icons + 'remove'), QCoreApplication.translate("mainwindow_ui_tr", 'Remove Selected Downloads from List'),
+                                            self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Remove Selected Downloads from List'), triggered=self.removeSelected)
 
         self.removeSelectedAction_shortcut = QShortcut(
             self.persepolis_setting.value('remove_shortcut'), self, self.removeSelected)
@@ -638,8 +645,8 @@ class MainWindow_Ui(QMainWindow):
         self.removeSelectedAction.setEnabled(False)
 
         # deleteSelectedAction
-        self.deleteSelectedAction = QAction(QIcon(icons + 'trash'), QCoreApplication.translate("mainwindow_ui_tr", 'Delete selected download files'),
-                                            self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Delete selected download files'), triggered=self.deleteSelected)
+        self.deleteSelectedAction = QAction(QIcon(icons + 'trash'), QCoreApplication.translate("mainwindow_ui_tr", 'Delete Selected Download Files'),
+                                            self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Delete Selected Download Files'), triggered=self.deleteSelected)
 
         self.deleteSelectedAction_shortcut = QShortcut(
             self.persepolis_setting.value('delete_shortcut'), self, self.deleteSelected)
@@ -648,36 +655,36 @@ class MainWindow_Ui(QMainWindow):
         self.deleteSelectedAction.setEnabled(False)
 
         # moveSelectedDownloadsAction
-        self.moveSelectedDownloadsAction = QAction(QIcon(icons + 'folder'), QCoreApplication.translate("mainwindow_ui_tr", 'move selected download files to another folder'),
-                                                   self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'move selected download files to another folder'), triggered=self.moveSelectedDownloads)
+        self.moveSelectedDownloadsAction = QAction(QIcon(icons + 'folder'), QCoreApplication.translate("mainwindow_ui_tr", 'Move Selected Download Files to Another Folder...'),
+                                                   self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Move Selected Download Files to Another Folder'), triggered=self.moveSelectedDownloads)
 
         editMenu.addAction(self.moveSelectedDownloadsAction)
         self.moveSelectedDownloadsAction.setEnabled(False)
 
         # createQueueAction
-        self.createQueueAction = QAction(QIcon(icons + 'add_queue'), QCoreApplication.translate("mainwindow_ui_tr", 'Create new queue'),
+        self.createQueueAction = QAction(QIcon(icons + 'add_queue'), QCoreApplication.translate("mainwindow_ui_tr", 'Create New Queue...'),
                                          self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Create new download queue'), triggered=self.createQueue)
         queueMenu.addAction(self.createQueueAction)
 
         # removeQueueAction
-        self.removeQueueAction = QAction(QIcon(icons + 'remove_queue'), QCoreApplication.translate("mainwindow_ui_tr", 'Remove this queue'),
+        self.removeQueueAction = QAction(QIcon(icons + 'remove_queue'), QCoreApplication.translate("mainwindow_ui_tr", 'Remove Queue'),
                                          self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Remove this queue'), triggered=self.removeQueue)
         queueMenu.addAction(self.removeQueueAction)
 
         # startQueueAction
         self.startQueueAction = QAction(QIcon(
-            icons + 'start_queue'), QCoreApplication.translate("mainwindow_ui_tr", 'Start this queue'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Start this queue'), triggered=self.startQueue)
+            icons + 'start_queue'), QCoreApplication.translate("mainwindow_ui_tr", 'Start this queue'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Start Queue'), triggered=self.startQueue)
 
         queueMenu.addAction(self.startQueueAction)
 
         # stopQueueAction
         self.stopQueueAction = QAction(QIcon(
-            icons + 'stop_queue'), QCoreApplication.translate("mainwindow_ui_tr", 'Stop this queue'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Stop this queue'), triggered=self.stopQueue)
+            icons + 'stop_queue'), QCoreApplication.translate("mainwindow_ui_tr", 'Stop this queue'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Stop Queue'), triggered=self.stopQueue)
 
         queueMenu.addAction(self.stopQueueAction)
 
         # moveUpSelectedAction
-        self.moveUpSelectedAction = QAction(QIcon(icons + 'multi_up'), QCoreApplication.translate("mainwindow_ui_tr", 'Move up selected items'), self,
+        self.moveUpSelectedAction = QAction(QIcon(icons + 'multi_up'), QCoreApplication.translate("mainwindow_ui_tr", 'Move Selected Items Up'), self,
                                             statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Move currently selected items up by one row'), triggered=self.moveUpSelected)
 
         self.moveUpSelectedAction_shortcut = QShortcut(self.persepolis_setting.value(
@@ -686,7 +693,7 @@ class MainWindow_Ui(QMainWindow):
         queueMenu.addAction(self.moveUpSelectedAction)
 
         # moveDownSelectedAction
-        self.moveDownSelectedAction = QAction(QIcon(icons + 'multi_down'), QCoreApplication.translate("mainwindow_ui_tr", 'Move down selected items'),
+        self.moveDownSelectedAction = QAction(QIcon(icons + 'multi_down'), QCoreApplication.translate("mainwindow_ui_tr", 'Move Selected Items Down'),
                                               self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Move currently selected items down by one row'), triggered=self.moveDownSelected)
         self.moveDownSelectedAction_shortcut = QShortcut(self.persepolis_setting.value(
             'move_down_selection_shortcut'), self, self.moveDownSelected)
@@ -695,26 +702,26 @@ class MainWindow_Ui(QMainWindow):
 
         # preferencesAction
         self.preferencesAction = QAction(QIcon(icons + 'preferences'), QCoreApplication.translate("mainwindow_ui_tr", 'Preferences'),
-                                         self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Preferences'), triggered=self.openPreferences, menuRole=5)
+                                         self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Preferences'), triggered=self.openPreferences, menuRole=QAction.MenuRole.PreferencesRole)
         editMenu.addAction(self.preferencesAction)
 
         # aboutAction
         self.aboutAction = QAction(QIcon(
-            icons + 'about'), QCoreApplication.translate("mainwindow_ui_tr", 'About'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'About'), triggered=self.openAbout, menuRole=4)
+            icons + 'about'), QCoreApplication.translate("mainwindow_ui_tr", 'About'), self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'About'), triggered=self.openAbout, menuRole=QAction.MenuRole.AboutRole)
         helpMenu.addAction(self.aboutAction)
 
         # issueAction
-        self.issueAction = QAction(QIcon(icons + 'about'), QCoreApplication.translate("mainwindow_ui_tr", 'Report an issue'),
+        self.issueAction = QAction(QIcon(icons + 'about'), QCoreApplication.translate("mainwindow_ui_tr", 'Report an Issue'),
                                    self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Report an issue'), triggered=self.reportIssue)
         helpMenu.addAction(self.issueAction)
 
         # updateAction
-        self.updateAction = QAction(QIcon(icons + 'about'), QCoreApplication.translate("mainwindow_ui_tr", 'Check for newer version'),
+        self.updateAction = QAction(QIcon(icons + 'about'), QCoreApplication.translate("mainwindow_ui_tr", 'Check for Newer Version'),
                                     self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Check for newer release'), triggered=self.newUpdate)
         helpMenu.addAction(self.updateAction)
 
         # logAction
-        self.logAction = QAction(QIcon(icons + 'about'), QCoreApplication.translate("mainwindow_ui_tr", 'Show log file'),
+        self.logAction = QAction(QIcon(icons + 'about'), QCoreApplication.translate("mainwindow_ui_tr", 'Show Log File'),
                                  self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Help'), triggered=self.showLog)
         helpMenu.addAction(self.logAction)
 
@@ -731,7 +738,7 @@ class MainWindow_Ui(QMainWindow):
 
 
 # labels
-        self.queue_panel_show_button.setText(QCoreApplication.translate("mainwindow_ui_tr", "Hide options"))
+        self.queue_panel_show_button.setText(QCoreApplication.translate("mainwindow_ui_tr", "Hide Options"))
         self.start_checkBox.setText(QCoreApplication.translate("mainwindow_ui_tr", "Start Time"))
 
         self.end_checkBox.setText(QCoreApplication.translate("mainwindow_ui_tr", "End Time"))
@@ -747,17 +754,17 @@ class MainWindow_Ui(QMainWindow):
         self.after_checkBox.setText(QCoreApplication.translate("mainwindow_ui_tr", "After download"))
         self.after_comboBox.setItemText(0, QCoreApplication.translate("mainwindow_ui_tr", "Shut Down"))
 
-        self.keep_awake_checkBox.setText(QCoreApplication.translate("mainwindow_ui_tr", "Keep system awake!"))
+        self.keep_awake_checkBox.setText(QCoreApplication.translate("mainwindow_ui_tr", "Keep System Awake!"))
         self.keep_awake_checkBox.setToolTip(
-            QCoreApplication.translate("mainwindow_ui_tr", "<html><head/><body><p>This option is preventing system from going to sleep.\
-            This is necessary if your power manager is suspending system automatically. </p></body></html>"))
+            QCoreApplication.translate("mainwindow_ui_tr", "<html><head/><body><p>This option will prevent the system from going to sleep.\
+            It is necessary if your power manager is suspending the system automatically. </p></body></html>"))
 
         self.after_pushButton.setText(QCoreApplication.translate("mainwindow_ui_tr", "Apply"))
 
-        self.muxing_pushButton.setText(QCoreApplication.translate("mainwindow_ui_tr", "start muxing"))
+        self.muxing_pushButton.setText(QCoreApplication.translate("mainwindow_ui_tr", "Start Mixing"))
 
-        self.video_label.setText(QCoreApplication.translate("mainwindow_ui_tr", "<b>Video file status: </b>"))
-        self.audio_label.setText(QCoreApplication.translate("mainwindow_ui_tr", "<b>Audio file status: </b>"))
+        self.video_label.setText(QCoreApplication.translate("mainwindow_ui_tr", "<b>Video File Status: </b>"))
+        self.audio_label.setText(QCoreApplication.translate("mainwindow_ui_tr", "<b>Audio File Status: </b>"))
 
         self.video_finder_status_label.setText(QCoreApplication.translate("mainwindow_ui_tr", "<b>Status: </b>"))
-        self.muxing_status_label.setText(QCoreApplication.translate("mainwindow_ui_tr", "<b>Muxing status: </b>"))
+        self.muxing_status_label.setText(QCoreApplication.translate("mainwindow_ui_tr", "<b>Mixing status: </b>"))
