@@ -13,14 +13,17 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+try:
+    from PySide6.QtWidgets import QAbstractItemView, QTableWidget, QTableWidgetItem, QCheckBox, QVBoxLayout, QHBoxLayout, QFrame, QWidget, QLabel, QLineEdit, QTabWidget, QSpinBox, QPushButton, QDial, QComboBox, QFontComboBox, QSpacerItem, QSizePolicy
+    from PySide6.QtCore import Qt, QTranslator, QCoreApplication, QLocale
+    from PySide6.QtGui import QIcon
+except:
+    from PyQt5.QtWidgets import QAbstractItemView, QTableWidget, QTableWidgetItem, QCheckBox, QVBoxLayout, QHBoxLayout, QFrame, QWidget, QLabel, QLineEdit, QTabWidget, QSpinBox, QPushButton, QDial, QComboBox, QFontComboBox, QSpacerItem, QSizePolicy
+    from PyQt5.QtCore import Qt, QTranslator, QCoreApplication, QLocale
+    from PyQt5.QtGui import QIcon
 
-from PyQt5.QtWidgets import QAbstractItemView, QTableWidget, QTableWidgetItem, QCheckBox, QVBoxLayout, QHBoxLayout, QFrame, QWidget, QLabel, QLineEdit, QTabWidget, QSpinBox, QPushButton, QDial, QComboBox, QFontComboBox, QSpacerItem, QSizePolicy
-from PyQt5.QtCore import Qt, QTranslator, QCoreApplication, QLocale
 from persepolis.gui.customized_widgets import MyQDateTimeEdit
 from persepolis.gui import resources
-from PyQt5.QtGui import QIcon
-import pkg_resources
-
 
 class KeyCapturingWindow_Ui(QWidget):
     def __init__(self, persepolis_setting):
@@ -192,6 +195,10 @@ class Setting_Ui(QWidget):
         download_options_tab_verticalLayout.addLayout(
             wait_queue_horizontalLayout)
 
+        # don't check certificate checkBox
+        self.dont_check_certificate_checkBox = QCheckBox(self.download_options_tab)
+        download_options_tab_verticalLayout.addWidget(self.dont_check_certificate_checkBox)
+
         # change aria2 path
         aria2_path_verticalLayout = QVBoxLayout()
 
@@ -319,7 +326,7 @@ class Setting_Ui(QWidget):
 
         style_tab_verticalLayout.addLayout(language_horizontalLayout)
         language_horizontalLayout = QHBoxLayout()
-        self.lang_label.setText(QCoreApplication.translate("setting_ui_tr", "Language:"))
+        self.lang_label.setText(QCoreApplication.translate("setting_ui_tr", "Language: "))
 
         # color scheme
         self.color_label = QLabel(self.style_tab)
@@ -500,14 +507,14 @@ class Setting_Ui(QWidget):
 
         # Actions
         actions_list = [QCoreApplication.translate('setting_ui_tr', 'Quit'),
-                        QCoreApplication.translate('setting_ui_tr', 'Minimize main window to the tray icon'),
-                        QCoreApplication.translate('setting_ui_tr', 'Remove download items'),
-                        QCoreApplication.translate('setting_ui_tr', 'Delete download items'),
-                        QCoreApplication.translate('setting_ui_tr', 'Move up selected items'),
-                        QCoreApplication.translate('setting_ui_tr', 'Move down selected items'),
-                        QCoreApplication.translate('setting_ui_tr', 'Add new download link'),
-                        QCoreApplication.translate('setting_ui_tr', 'Add new Video link'),
-                        QCoreApplication.translate('setting_ui_tr', 'Import links from text file')]
+                        QCoreApplication.translate('setting_ui_tr', 'Minimize to System Tray'),
+                        QCoreApplication.translate('setting_ui_tr', 'Remove Download Items'),
+                        QCoreApplication.translate('setting_ui_tr', 'Delete Download Items'),
+                        QCoreApplication.translate('setting_ui_tr', 'Move Selected Items Up'),
+                        QCoreApplication.translate('setting_ui_tr', 'Move Selected Items Down'),
+                        QCoreApplication.translate('setting_ui_tr', 'Add New Download Link'),
+                        QCoreApplication.translate('setting_ui_tr', 'Add New Video Link'),
+                        QCoreApplication.translate('setting_ui_tr', 'Import Links from Text File')]
 
         # add actions to the shortcut_table
         j = 0
@@ -556,7 +563,7 @@ class Setting_Ui(QWidget):
 
         self.wait_label.setToolTip(
             QCoreApplication.translate("setting_ui_tr", "<html><head/><body><p>Set the seconds to wait between retries. Download manager will  retry  downloads  when  the  HTTP  server  returns  a  503 response.</p></body></html>"))
-        self.wait_label.setText(QCoreApplication.translate("setting_ui_tr", "Wait between retries (seconds): "))
+        self.wait_label.setText(QCoreApplication.translate("setting_ui_tr", "Wait period between retries (seconds): "))
         self.wait_spinBox.setToolTip(
             QCoreApplication.translate("setting_ui_tr", "<html><head/><body><p>Set the seconds to wait between retries. Download manager will  retry  downloads  when  the  HTTP  server  returns  a  503 response.</p></body></html>"))
 
@@ -577,12 +584,16 @@ class Setting_Ui(QWidget):
             QCoreApplication.translate("setting_ui_tr", "<html><head/><body><p> Specify a port number for JSON-RPC/XML-RPC server to listen to. Possible Values: 1024 - 65535 Default: 6801 </p></body></html>"))
 
         self.wait_queue_label.setText(QCoreApplication.translate(
-            "setting_ui_tr", 'Wait between every downloads in queue:'))
+            "setting_ui_tr", 'Wait period between each download in queue:'))
+
+        self.dont_check_certificate_checkBox.setText(QCoreApplication.translate("setting_ui_tr", "Don't use certificate to verify the peers"))
+        self.dont_check_certificate_checkBox.setToolTip(
+                QCoreApplication.translate("setting_ui_tr", "<html><head/><body><p>This option avoids SSL/TLS handshake failure. But use it at your own risk!</p></body></html>"))
 
         self.aria2_path_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'Change Aria2 default path'))
         self.aria2_path_pushButton.setText(QCoreApplication.translate("setting_ui_tr", 'Change'))
         aria2_path_tooltip = QCoreApplication.translate(
-            "setting_ui_tr", "<html><head/><body><p>Attention: Wrong path may have caused problem! Do it carefully or don't change default setting!</p></body></html>")
+            "setting_ui_tr", "<html><head/><body><p>Attention: Wrong path may cause problems! Do it carefully or don't change default setting!</p></body></html>")
         self.aria2_path_checkBox.setToolTip(aria2_path_tooltip)
         self.aria2_path_lineEdit.setToolTip(aria2_path_tooltip)
         self.aria2_path_pushButton.setToolTip(aria2_path_tooltip)
@@ -590,20 +601,20 @@ class Setting_Ui(QWidget):
         self.setting_tabWidget.setTabText(self.setting_tabWidget.indexOf(
             self.download_options_tab),  QCoreApplication.translate("setting_ui_tr", "Download Options"))
 
-        self.download_folder_label.setText(QCoreApplication.translate("setting_ui_tr", "Download Folder: "))
+        self.download_folder_label.setText(QCoreApplication.translate("setting_ui_tr", "Download folder: "))
         self.download_folder_pushButton.setText(QCoreApplication.translate("setting_ui_tr", "Change"))
 
-        self.temp_download_label.setText(QCoreApplication.translate("setting_ui_tr", "Temporary Download Folder: "))
+        self.temp_download_label.setText(QCoreApplication.translate("setting_ui_tr", "Temporary download folder: "))
         self.temp_download_pushButton.setText(QCoreApplication.translate("setting_ui_tr", "Change"))
 
         self.subfolder_checkBox.setText(QCoreApplication.translate(
-            "setting_ui_tr", "Create subfolders for Music,Videos,... in default download folder"))
+            "setting_ui_tr", "Create subfolders for Music,Videos, ... in default download folder"))
 
         self.setting_tabWidget.setTabText(
-            self.setting_tabWidget.indexOf(self.save_as_tab),  QCoreApplication.translate("setting_ui_tr", "Save as"))
+            self.setting_tabWidget.indexOf(self.save_as_tab),  QCoreApplication.translate("setting_ui_tr", "Save As"))
 
         self.enable_notifications_checkBox.setText(
-            QCoreApplication.translate("setting_ui_tr", "Enable notification sounds"))
+            QCoreApplication.translate("setting_ui_tr", "Enable Notification Sounds"))
 
         self.volume_label.setText(QCoreApplication.translate("setting_ui_tr", "Volume: "))
 
@@ -614,7 +625,7 @@ class Setting_Ui(QWidget):
         self.color_label.setText(QCoreApplication.translate("setting_ui_tr", "Color scheme: "))
         self.icon_label.setText(QCoreApplication.translate("setting_ui_tr", "Icons: "))
 
-        self.icons_size_label.setText(QCoreApplication.translate("setting_ui_tr", "Toolbar's icons size: "))
+        self.icons_size_label.setText(QCoreApplication.translate("setting_ui_tr", "Toolbar icons size: "))
 
         self.notification_label.setText(QCoreApplication.translate("setting_ui_tr", "Notification type: "))
 
@@ -627,25 +638,25 @@ class Setting_Ui(QWidget):
             QCoreApplication.translate("setting_ui_tr", "<html><head/><body><p>This feature may not work in your operating system.</p></body></html>"))
 
         self.start_persepolis_if_browser_executed_checkBox.setText(
-            QCoreApplication.translate('setting_ui_tr', 'Start Persepolis in system tray, If browser is executed.'))
+            QCoreApplication.translate('setting_ui_tr', 'If browser is opened, start Persepolis in system tray'))
 
         self.enable_system_tray_checkBox.setText(
-            QCoreApplication.translate("setting_ui_tr", "Enable system tray icon."))
+            QCoreApplication.translate("setting_ui_tr", "Enable system tray icon"))
 
         self.after_download_checkBox.setText(
-            QCoreApplication.translate("setting_ui_tr", "Show download complete dialog when download has finished."))
+            QCoreApplication.translate("setting_ui_tr", "Show download complete dialog when download is finished"))
 
-        self.show_menubar_checkbox.setText(QCoreApplication.translate("setting_ui_tr", "Show menubar."))
-        self.show_sidepanel_checkbox.setText(QCoreApplication.translate("setting_ui_tr", "Show side panel."))
+        self.show_menubar_checkbox.setText(QCoreApplication.translate("setting_ui_tr", "Show menubar"))
+        self.show_sidepanel_checkbox.setText(QCoreApplication.translate("setting_ui_tr", "Show side panel"))
         self.show_progress_window_checkbox.setText(
-            QCoreApplication.translate("setting_ui_tr", "Show download's progress window"))
+            QCoreApplication.translate("setting_ui_tr", "Show download progress window"))
 
         self.startup_checkbox.setText(QCoreApplication.translate("setting_ui_tr", "Run Persepolis at startup"))
 
         self.keep_awake_checkBox.setText(QCoreApplication.translate("setting_ui_tr", "Keep system awake!"))
         self.keep_awake_checkBox.setToolTip(
-            QCoreApplication.translate("setting_ui_tr", "<html><head/><body><p>This option is preventing system from going to sleep.\
-            This is necessary if your power manager is suspending system automatically. </p></body></html>"))
+            QCoreApplication.translate("setting_ui_tr", "<html><head/><body><p>This option will prevent the system from going to sleep.\
+            It is necessary if your power manager is suspending the system automatically. </p></body></html>"))
 
         self.wait_queue_time.setToolTip(
             QCoreApplication.translate("setting_ui_tr", "<html><head/><body><p>Format HH:MM</p></body></html>"))
@@ -654,21 +665,21 @@ class Setting_Ui(QWidget):
             self.setting_tabWidget.indexOf(self.style_tab),  QCoreApplication.translate("setting_ui_tr", "Preferences"))
 
 # columns_tab
-        self.show_column_label.setText(QCoreApplication.translate("setting_ui_tr", 'Show this columns:'))
+        self.show_column_label.setText(QCoreApplication.translate("setting_ui_tr", 'Show these columns:'))
         self.column0_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'File Name'))
         self.column1_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'Status'))
         self.column2_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'Size'))
         self.column3_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'Downloaded'))
         self.column4_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'Percentage'))
         self.column5_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'Connections'))
-        self.column6_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'Transfer rate'))
-        self.column7_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'Estimated time left'))
-        self.column10_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'First try date'))
-        self.column11_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'Last try date'))
+        self.column6_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'Transfer Rate'))
+        self.column7_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'Estimated Time Left'))
+        self.column10_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'First Try Date'))
+        self.column11_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'Last Try Date'))
         self.column12_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'Category'))
 
         self.setting_tabWidget.setTabText(
-            self.setting_tabWidget.indexOf(self.columns_tab), QCoreApplication.translate("setting_ui_tr", "Columns customization"))
+            self.setting_tabWidget.indexOf(self.columns_tab), QCoreApplication.translate("setting_ui_tr", "Columns Customization"))
 
 # Video Finder options tab
         self.setting_tabWidget.setTabText(self.setting_tabWidget.indexOf(
