@@ -14,14 +14,20 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
+try:
+    from PySide6.QtWidgets import QHBoxLayout, QApplication, QFileDialog, QCheckBox, QLineEdit, QPushButton
+    from PySide6.QtCore import Qt, QPoint, QSize, QDir, QThread, Signal
+    from PySide6.QtGui import QIcon
+except:
+    from PyQt5.QtWidgets import QHBoxLayout, QApplication, QFileDialog, QCheckBox, QLineEdit, QPushButton
+    from PyQt5.QtCore import Qt, QPoint, QSize, QDir, QThread
+    from PyQt5.QtGui import QIcon
+    from PyQt5.QtCore import pyqtSignal as Signal
 
-from PyQt5.QtWidgets import QHBoxLayout, QApplication, QFileDialog, QCheckBox, QLineEdit, QPushButton
-from PyQt5.QtCore import Qt, QPoint, QSize, QDir, QThread, pyqtSignal
 from persepolis.gui.addlink_ui import AddLinkWindow_Ui
 from persepolis.scripts.check_proxy import getProxy
 from persepolis.scripts import spider
 from persepolis.scripts import logger
-from PyQt5.QtGui import QIcon
 from functools import partial
 import os
 
@@ -29,7 +35,7 @@ import os
 
 
 class AddLinkSpiderThread(QThread):
-    ADDLINKSPIDERSIGNAL = pyqtSignal(dict)
+    ADDLINKSPIDERSIGNAL = Signal(dict)
 
     def __init__(self, add_link_dictionary):
         QThread.__init__(self)
@@ -145,7 +151,7 @@ class AddLinkWindow(AddLinkWindow_Ui):
         # connect folder_pushButton
         self.folder_pushButton.clicked.connect(self.changeFolder)
 
-        # connect OK and canel download_later button ->
+        # connect OK and cancel download_later button ->
         self.cancel_pushButton.clicked.connect(self.close)
         self.ok_pushButton.clicked.connect(partial(
             self.okButtonPressed, download_later=False))
@@ -300,8 +306,8 @@ class AddLinkWindow(AddLinkWindow_Ui):
             # spider is finding file size
             new_spider = AddLinkSpiderThread(dict)
             self.parent.threadPool.append(new_spider)
-            self.parent.threadPool[len(self.parent.threadPool) - 1].start()
-            self.parent.threadPool[len(self.parent.threadPool) - 1].ADDLINKSPIDERSIGNAL.connect(
+            self.parent.threadPool[-1].start()
+            self.parent.threadPool[-1].ADDLINKSPIDERSIGNAL.connect(
                 partial(self.parent.addLinkSpiderCallBack, child=self))
 
             self.ok_pushButton.setEnabled(True)
@@ -328,8 +334,8 @@ class AddLinkWindow(AddLinkWindow_Ui):
             self.start_checkBox.setEnabled(True)
             self.end_checkBox.setEnabled(True)
 
-    def okButtonPressed(self, button, download_later):
-        # user commited information by pressing ok_pushButton, so get information
+    def okButtonPressed(self, download_later, button=None):
+        # user submitted information by pressing ok_pushButton, so get information
         # from AddLinkWindow and return them to the mainwindow with callback!
 
         # write user's new inputs in persepolis_setting for next time :)
@@ -342,6 +348,11 @@ class AddLinkWindow(AddLinkWindow_Ui):
         self.persepolis_setting.setValue(
             'add_link_initialization/download_user', self.download_user_lineEdit.text())
 
+        # Check 'Remember path' and change default path if needed
+        if self.folder_checkBox.isChecked() == True:
+            self.persepolis_setting.setValue(
+                'settings/download_path', self.download_folder_lineEdit.text())
+
         # get proxy information
         if not(self.proxy_checkBox.isChecked()):
             ip = None
@@ -452,10 +463,13 @@ class AddLinkWindow(AddLinkWindow_Ui):
         # close window
         self.close()
 
-
-# save size and position of window, when user closes the window.
+    # close window with ESC key
+    def keyPressEvent(self, event):
+        if event.key() == Qt.Key_Escape:
+            self.close()
 
 
+    # save size and position of window, when user closes the window.
     def closeEvent(self, event):
         self.persepolis_setting.setValue('AddLinkWindow/size', self.size())
         self.persepolis_setting.setValue('AddLinkWindow/position', self.pos())
