@@ -12,12 +12,19 @@
 #
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+try:
+    from PySide6.QtCore import Qt, QEvent, QTime, QSize, QPoint, QDir, QTranslator, QCoreApplication, QLocale
+    from PySide6.QtWidgets import QFileDialog, QStyleFactory, QMessageBox, QTableWidgetItem
+    from PySide6.QtGui import QFont, QKeySequence
+except:
+    from PyQt5.QtCore import Qt, QEvent, QTime, QSize, QPoint, QDir, QTranslator, QCoreApplication, QLocale
+    from PyQt5.QtWidgets import QFileDialog, QStyleFactory, QMessageBox, QTableWidgetItem
+    from PyQt5.QtGui import QFont, QKeySequence
 
-from PyQt5.QtCore import Qt, QEvent, QTime, QSize, QPoint, QDir, QTranslator, QCoreApplication, QLocale
-from PyQt5.QtWidgets import QFileDialog, QStyleFactory, QMessageBox, QTableWidgetItem
+
+from persepolis.constants import OS
 from persepolis.gui.setting_ui import Setting_Ui, KeyCapturingWindow_Ui
 from persepolis.scripts.useful_tools import returnDefaultSettings
-from PyQt5.QtGui import QFont, QKeySequence
 from persepolis.scripts import osCommands
 from persepolis.scripts import startup
 import platform
@@ -77,6 +84,12 @@ class PreferencesWindow(Setting_Ui):
         self.rpc_port_spinbox.setValue(
             int(self.persepolis_setting.value('rpc-port')))
 
+        if str(self.persepolis_setting.value('dont-check-certificate')) == 'yes':
+            self.dont_check_certificate_checkBox.setChecked(True)
+        else:
+            self.dont_check_certificate_checkBox.setChecked(False)
+
+
         # add support for other languages
         locale = str(self.persepolis_setting.value('settings/locale'))
         QLocale.setDefault(QLocale(locale))
@@ -86,7 +99,11 @@ class PreferencesWindow(Setting_Ui):
 
         # wait_queue
         wait_queue_list = self.persepolis_setting.value('wait-queue')
-        q_time = QTime(int(wait_queue_list[0]), int(wait_queue_list[1]))
+        try:
+            q_time = QTime(int(wait_queue_list[0]), int(wait_queue_list[1]))
+        except:
+            q_time = QTime(0, 0)
+
         self.wait_queue_time.setTime(q_time)
 
         # change aria2 path
@@ -101,7 +118,7 @@ class PreferencesWindow(Setting_Ui):
 
         self.ariaCheckBoxToggled('aria2')
 
-        if os_type == 'Linux' or os_type == 'FreeBSD' or os_type == 'OpenBSD':
+        if os_type in OS.UNIX_LIKE:
             for widget in self.aria2_path_checkBox, self.aria2_path_lineEdit, self.aria2_path_pushButton:
                 widget.hide()
 
@@ -127,8 +144,11 @@ class PreferencesWindow(Setting_Ui):
         # find available styles(It's depends on operating system and desktop environments).
         available_styles = QStyleFactory.keys()
         for style in available_styles:
-            # 'GTK' or 'gtk' styles may cause to crashing! Eliminate them!
-            if 'gtk' not in str(style) and 'GTK' not in str(style):
+
+            # 'bb10dark', 'GTK', 'gtk' styles may cause to crashing! Eliminate them!
+            style_black_list = ['bb10dark', 'bb10bright', 'GTK', 'gtk', 'gtk2']
+
+            if style not in style_black_list:
                 self.style_comboBox.addItem(style)
 
         # System >> for system default style
@@ -141,7 +161,7 @@ class PreferencesWindow(Setting_Ui):
             self.style_comboBox.setCurrentIndex(current_style_index)
 
         # available language
-        available_language = ['en_US', 'fa_IR', 'ar', 'zh_CN', 'fr_FR', 'pl_PL', 'nl_NL', 'pt_BR', 'es_ES', 'hu']
+        available_language = ['en_US', 'fa_IR', 'ar', 'zh_CN', 'fr_FR', 'pl_PL', 'nl_NL', 'pt_BR', 'es_ES', 'hu', 'tr', 'tr_TR']
         for lang in available_language:
             self.lang_comboBox.addItem(str(QLocale(lang).nativeLanguageName()), lang)
 
@@ -406,7 +426,7 @@ class PreferencesWindow(Setting_Ui):
         keyboard_capture_window = KeyCapturingWindow(self.callBack, self.persepolis_setting)
 
         self.parent.capturekeywindows_list.append(keyboard_capture_window)
-        self.parent.capturekeywindows_list[len(self.parent.capturekeywindows_list) - 1].show()
+        self.parent.capturekeywindows_list[-1].show()
 
     def callBack(self, keys):
         # do nothing if keys is empty
@@ -470,14 +490,14 @@ class PreferencesWindow(Setting_Ui):
             current_color_index = self.color_comboBox.findText(
                 str(self.persepolis_setting.value('color-scheme')))
 
-            # it means user's prefered color_scheme is not valid in color_comboBox.
+            # it means user's preferred color_scheme is not valid in color_comboBox.
             if current_color_index == -1:
                 current_color_index = 0
 
             self.color_comboBox.setCurrentIndex(current_color_index)
 
         self.setDarkLightIcon()
-            
+
     # this method sets dark icons for dark color schemes
     # and light icons for light color schemes.
     def setDarkLightIcon(self, index=None):
@@ -566,7 +586,7 @@ class PreferencesWindow(Setting_Ui):
 
     def fontCheckBoxState(self, checkBox):
 
-        # deactive fontComboBox and font_size_spinBox if font_checkBox not checked!
+        # deactivate fontComboBox and font_size_spinBox if font_checkBox not checked!
         if self.font_checkBox.isChecked():
             self.fontComboBox.setEnabled(True)
             self.font_size_spinBox.setEnabled(True)
@@ -574,6 +594,12 @@ class PreferencesWindow(Setting_Ui):
             self.fontComboBox.setEnabled(False)
             self.font_size_spinBox.setEnabled(False)
 
+    # close window with ESC key
+    def keyPressEvent(self, event):
+        if event.key() == Qt.Key_Escape:
+            self.close()
+
+
     def closeEvent(self, event):
 
         # saving window size and position
@@ -668,6 +694,9 @@ class PreferencesWindow(Setting_Ui):
         q_time = QTime(wait_queue_list[0], wait_queue_list[1])
         self.wait_queue_time.setTime(q_time)
 
+        # dont_check_certificate_checkBox
+        self.dont_check_certificate_checkBox.setChecked(False)
+
         # save_as_tab
         self.download_folder_lineEdit.setText(
             str(self.setting_dict['download_path']))
@@ -823,6 +852,14 @@ class PreferencesWindow(Setting_Ui):
         if self.aria2_path_checkBox.isChecked():
             self.persepolis_setting.setValue('settings/aria2_path', str(self.aria2_path_lineEdit.text()))
 
+        # don't check certificate
+        if self.dont_check_certificate_checkBox.isChecked():
+            self.persepolis_setting.setValue('dont-check-certificate', 'yes')
+        else:
+            self.persepolis_setting.setValue('dont-check-certificate', 'no')
+
+
+
         # changing icons
 
         icons = self.icon_comboBox.currentText()
@@ -940,13 +977,13 @@ class PreferencesWindow(Setting_Ui):
         if self.startup_checkbox.isChecked():
             self.persepolis_setting.setValue('startup', 'yes')
 
-            if not(startup.checkstartup()):  # checking existance of Persepolis in  system's startup
+            if not(startup.checkstartup()):  # checking existence of Persepolis in  system's startup
 
                 startup.addstartup()  # adding Persepolis to system's startup
         else:
             self.persepolis_setting.setValue('startup', 'no')
 
-            if startup.checkstartup():  # checking existance of Persepolis in  system's startup
+            if startup.checkstartup():  # checking existence of Persepolis in  system's startup
 
                 startup.removestartup()  # removing Persepolis from system's startup
 
