@@ -13,9 +13,14 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
+try:
+    from PySide6.QtWidgets import QCheckBox, QPushButton, QTextEdit, QFrame, QLabel, QComboBox, QHBoxLayout, QApplication
+    from PySide6.QtCore import Qt, QThread, Signal, QCoreApplication, QTranslator, QLocale
+except:
+    from PyQt5.QtWidgets import QCheckBox, QPushButton, QTextEdit, QFrame, QLabel, QComboBox, QHBoxLayout, QApplication
+    from PyQt5.QtCore import Qt, QThread, QCoreApplication, QTranslator, QLocale
+    from PyQt5.QtCore import pyqtSignal as Signal
 
-from PyQt5.QtWidgets import QCheckBox, QPushButton, QTextEdit, QFrame, QLabel, QComboBox, QHBoxLayout, QApplication
-from PyQt5.QtCore import QThread, pyqtSignal, QCoreApplication, QTranslator, QLocale
 from persepolis.scripts.useful_tools import determineConfigFolder
 from persepolis.scripts.addlink import AddLinkWindow
 from persepolis.scripts import logger, osCommands
@@ -24,7 +29,7 @@ from time import time, sleep
 from functools import partial
 from random import random
 from copy import deepcopy
-import youtube_dl
+import yt_dlp as youtube_dl
 import re
 import os
 
@@ -41,7 +46,7 @@ persepolis_tmp = os.path.join(config_folder, 'persepolis_tmp')
 
 
 class MediaListFetcherThread(QThread):
-    RESULT = pyqtSignal(dict)
+    RESULT = Signal(dict)
     cookies = '# HTTP cookie file.\n'  # We shall write it in a file when thread starts.
 
     def __init__(self, receiver_slot, video_dict, parent):
@@ -146,7 +151,7 @@ class MediaListFetcherThread(QThread):
 
 
 class FileSizeFetcherThread(QThread):
-    FOUND = pyqtSignal(dict)
+    FOUND = Signal(dict)
 
     def __init__(self, dictionary, thread_key):
         super().__init__()
@@ -199,8 +204,8 @@ class VideoFinderAddLink(AddLinkWindow):
         select_format_horizontalLayout = QHBoxLayout()
 
         # Selection Label
-        select_format_label = QLabel(self.link_frame)
-        select_format_horizontalLayout.addWidget(select_format_label)
+        self.select_format_label = QLabel(self.link_frame)
+        select_format_horizontalLayout.addWidget(self.select_format_label)
 
         # Selection combobox
         self.media_comboBox = QComboBox(self.link_frame)
@@ -241,7 +246,7 @@ class VideoFinderAddLink(AddLinkWindow):
 
         # Set Texts
         self.url_submit_pushButtontton.setText(QCoreApplication.translate("ytaddlink_src_ui_tr", 'Fetch Media List'))
-        select_format_label.setText(QCoreApplication.translate("ytaddlink_src_ui_tr", 'Select a format'))
+        self.select_format_label.setText(QCoreApplication.translate("ytaddlink_src_ui_tr", 'Select a format'))
 
         self.video_format_selection_label.setText(QCoreApplication.translate("ytaddlink_src_ui_tr", 'Video format:'))
         self.audio_format_selection_label.setText(QCoreApplication.translate("ytaddlink_src_ui_tr", 'Audio format:'))
@@ -361,7 +366,7 @@ class VideoFinderAddLink(AddLinkWindow):
 
         fetcher_thread = MediaListFetcherThread(self.fetchedResult, dictionary_to_send, self)
         self.parent.threadPool.append(fetcher_thread)
-        self.parent.threadPool[len(self.parent.threadPool) - 1].start()
+        self.parent.threadPool[-1].start()
 
     def fileNameChanged(self, value):
         if value.strip() == '':
@@ -482,9 +487,8 @@ class VideoFinderAddLink(AddLinkWindow):
                         size_fetcher = FileSizeFetcherThread(input_dict, i)
                         self.threadPool[str(i)] = {'thread': size_fetcher, 'item_id': i}
                         self.parent.threadPool.append(size_fetcher)
-                        self.parent.threadPool[len(self.parent.threadPool) - 1].start()
-                        self.parent.threadPool[len(self.parent.threadPool) -
-                                               1].FOUND.connect(self.findFileSize)
+                        self.parent.threadPool[-1].start()
+                        self.parent.threadPool[-1].FOUND.connect(self.findFileSize)
 
                     # Add current format to the related comboboxes
                     if no_audio:
@@ -512,15 +516,21 @@ class VideoFinderAddLink(AddLinkWindow):
                 self.ok_pushButton.setEnabled(True)
                 self.download_later_pushButton.setEnabled(True)
 
-                # if we have no options for seperate audio and video, then hide advanced_format_selection...
+                # if we have no options for separate audio and video, then hide advanced_format_selection...
                 if len(self.no_audio_list) == 0 and len(self.no_video_list) == 0:
                     self.advanced_format_selection_checkBox.hide()
                     self.advanced_format_selection_frame.hide()
 
                 # set index of comboboxes on best available quality.
+                # we have both audio and video
                 if len(self.no_audio_list) != 0 and len(self.no_video_list) != 0:
                     self.media_comboBox.addItem('Best quality')
                     self.media_comboBox.setCurrentIndex(len(self.video_audio_list))
+                    self.change_name_lineEdit.setText(self.media_title)
+                    self.extension_label.setText('.' + self.no_audio_list[-1]['ext'])
+                    self.change_name_checkBox.setChecked(True)
+
+                # video and audio are not separate
                 elif len(self.video_audio_list) != 0:
                     self.media_comboBox.setCurrentIndex(len(self.video_audio_list) - 1)
 
@@ -530,7 +540,26 @@ class VideoFinderAddLink(AddLinkWindow):
                 if len(self.no_video_list) != 0:
                     self.audio_format_selection_comboBox.setCurrentIndex(len(self.no_video_list))
 
-                self.mediaSelectionChanged('video_audio', int(self.media_comboBox.currentIndex()))
+                # if we have only audio or we have only video then hide media_comboBox
+                if len(self.video_audio_list) == 0:
+                    self.media_comboBox.hide()
+                    self.select_format_label.hide()
+
+                    # only video
+                    if len(self.no_video_list) != 0 and len(self.no_audio_list) == 0:
+                        self.mediaSelectionChanged('video', int(self.video_format_selection_comboBox.currentIndex()))
+                        self.advanced_format_selection_checkBox.setChecked(True)
+                        self.advanced_format_selection_checkBox.hide()
+
+                    # only audio
+                    elif len(self.no_video_list) == 0 and len(self.no_audio_list) != 0:
+                        self.mediaSelectionChanged('audio', int(self.audio_format_selection_comboBox.currentIndex()))
+                        self.advanced_format_selection_checkBox.setChecked(True)
+                        self.advanced_format_selection_checkBox.hide()
+
+                    # audio and video
+                    else:
+                        self.mediaSelectionChanged('video_audio', int(self.media_comboBox.currentIndex()))
 
             except Exception as ex:
                 logger.sendToLog(ex, "ERROR")
@@ -570,12 +599,12 @@ class VideoFinderAddLink(AddLinkWindow):
                 options[i] = None
         return options
 
-    # user commited information by pressing ok_pushButton, so get information
+    # user submitted information by pressing ok_pushButton, so get information
     # from VideoFinderAddLink window and return them to the mainwindow with callback!
-    def okButtonPressed(self, button, download_later):
+    def okButtonPressed(self, download_later, button=None):
 
         link_list = []
-        # seperate audio format and video format is selected.
+        # separate audio format and video format is selected.
         if self.advanced_format_selection_checkBox.isChecked():
 
             if self.video_format_selection_comboBox.currentText() == 'No video' and self.audio_format_selection_comboBox.currentText() != 'No audio':
@@ -599,19 +628,22 @@ class VideoFinderAddLink(AddLinkWindow):
 
             elif self.video_format_selection_comboBox.currentText() == 'No video' and self.audio_format_selection_comboBox.currentText() == 'No audio':
 
-                # no video and no video selected! REALY?!. user is DRUNK! close the window! :))
+                # no video and audio is selected! REALLY?!. user is DRUNK! close the window! :))
                 self.close()
         else:
             if self.media_comboBox.currentText() == 'Best quality':
 
                 # the last item in no_video_list and no_audio_list are the best.
-                audio_link = self.no_video_list[-1]['url']
                 video_link = self.no_audio_list[-1]['url']
+                audio_link = self.no_video_list[-1]['url']
+
                 link_list = [video_link, audio_link]
+
             else:
                 audio_and_video_link = self.video_audio_list[self.media_comboBox.currentIndex()]['url']
                 link_list.append(audio_and_video_link)
 
+
         # write user's new inputs in persepolis_setting for next time :)
         self.persepolis_setting.setValue(
             'add_link_initialization/ip', self.ip_lineEdit.text())
@@ -691,7 +723,7 @@ class VideoFinderAddLink(AddLinkWindow):
         else:
             extension = str(self.extension_label.text())
 
-        # did user select seperate audio and video?
+        # did user select separate audio and video?
         if len(link_list) == 2:
             video_name = name + extension
             audio_name = name + '.' + \
